@@ -40,9 +40,6 @@ except ModuleNotFoundError:
     ShapelyPolygon = None
 
 # ckz relabel2项目定制映射
-colors = {'印刷体': (0, 255, 0), '手写体': (255, 255, 0), '印章': (255, 0, 0), 'old': (0, 0, 0),
-          '其他类': (0, 0, 0)}
-
 _COLORS = {
     '印刷体': '鲜绿色',
     '手写体': '黄色',
@@ -569,10 +566,16 @@ class XlMainWindow(MainWindow):
 
         self.add_point_to_edge_action = utils.qt.newCheckableAction(
             self,
-            self.tr("Add Point to Edge"),
+            self.tr("Add Point to Edge Enable"),
             tip=self.tr("选中shape的edge时，增加分割点"),
         )
 
+        self.delete_selected_shape_with_warning_action = utils.qt.newCheckableAction(
+            self,
+            self.tr("Delete Selected Shape With Warning"),
+            checked=True,
+        )
+
         # Lavel list context menu.
         labelMenu = QtWidgets.QMenu()
         utils.addActions(labelMenu, (edit, delete))
@@ -637,6 +640,7 @@ class XlMainWindow(MainWindow):
                 toggle_keep_prev_mode,
                 None,
                 self.add_point_to_edge_action,
+                self.delete_selected_shape_with_warning_action,
             ),
             # menu shown at right click
             menu=(
